import stan
import arviz as az
import pickle

"""
       D. Spiegelhalter (2019)
       The art of statistics: Learnig from data.
       Penguin Random House
       Table 10.2
"""
        #   Left arm    Right arm
data =  [  [   5,          9  ],      #  Female
           [  17,         23  ]   ]   #  Male


stan_code = """
        data {
            array[2, 2] int F;
        }
        transformed data {
            int row1_sum;
            int row2_sum;
            int total;
            row1_sum = F[1][1] + F[1][2];
            row2_sum = F[2][1] + F[2][2];
            total = sum(F[1]) + sum(F[2]);
        }
        parameters {
            real a;
            real b;
            real c;
        }
        model {
            a ~ normal(0.0, 10.0);
            b ~ normal(0.0, 10.0);
            c ~ normal(0.0, 10.0);
            row1_sum ~ binomial(total, inv_logit(a));
            F[1][1] ~ binomial(row1_sum, inv_logit(b));
            F[2][1] ~ binomial(row2_sum, inv_logit(b + c));
        }
"""
Data = {'F':data}
sm = stan.build(stan_code, data=Data)
fit = sm.sample()
print(fit)
"""
        MCMCサンプルの保存
"""
df_fit = fit.to_frame()
with open('logit_fit.pkl', 'wb') as f:
    pickle.dump(df_fit, f)
"""
      MCMCサンプルの統計量
"""
inf_data = az.from_pystan(posterior=fit, posterior_model=sm)
smmry = az.summary(inf_data)
print(smmry)
